==> office-ui-fabric-vue-7.0.26.tgz: package/lib/utilities/grid/GridCell.js <==
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { css } from '@uifabric-vue/utilities';
import BaseComponent from '../../components/BaseComponent.js';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import _mergeJSXProps from '../node_modules/@vue/babel-helper-vue-jsx-merge-props/dist/helper.js';
import '../../components/Button/BaseButton.js';
import { ActionButton } from '../../components/Button/ActionButton/ActionButton.js';
import '../../components/Button/DefaultButton/DefaultButton.js';
import '../../components/Button/PrimaryButton/PrimaryButton.js';
import '../../components/Button/CommandBarButton/CommandBarButton.js';
import '../../components/Button/CompoundButton/CompoundButton.js';
import '../../components/Button/IconButton/IconButton.js';
import '../../components/Button/MessageBarButton/MessageBarButton.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

var GridCell = function (_BaseComponent) {
  _inherits(GridCell, _BaseComponent);

  var _super = _createSuper(GridCell);

  function GridCell() {
    _classCallCheck(this, GridCell);

    return _super.apply(this, arguments);
  }

  _createClass(GridCell, [{
    key: "render",
    value: function render() {
      var _css;

      var h = arguments[0];
      var className = this.className,
          item = this.item,
          cellDisabledStyle = this.cellDisabledStyle,
          cellIsSelectedStyle = this.cellIsSelectedStyle,
          selected = this.selected,
          disabled = this.disabled;
      return h(ActionButton, _mergeJSXProps([{
        "class": css(className, (_css = {}, _defineProperty(_css, '' + cellIsSelectedStyle, selected), _defineProperty(_css, '' + cellDisabledStyle, disabled), _css)),
        "attrs": {
          "getClassNames": this.getClassNames
        }
      }, {
        scopedSlots: {
          flex: this.$scopedSlots["default"]
        }
      }]));
    }
  }]);

  return GridCell;
}(BaseComponent);

__decorate([Prop({
  type: Object,
  "default": function _default() {}
}), __metadata("design:type", Object)], GridCell.prototype, "item", void 0);

__decorate([Prop({
  type: Boolean
}), __metadata("design:type", Boolean)], GridCell.prototype, "disabled", void 0);

__decorate([Prop({
  type: Boolean
}), __metadata("design:type", Boolean)], GridCell.prototype, "selected", void 0);

__decorate([Prop({
  type: String
}), __metadata("design:type", String)], GridCell.prototype, "cellDisabledStyle", void 0);

__decorate([Prop({
  type: String
}), __metadata("design:type", String)], GridCell.prototype, "cellIsSelectedStyle", void 0);

__decorate([Prop(), __metadata("design:type", Object)], GridCell.prototype, "getClassNames", void 0);

GridCell = __decorate([Component({
  components: {
    ActionButton: ActionButton
  }
})], GridCell);

export { GridCell };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/utilities/grid/GridCell.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { css } from '@uifabric-vue/utilities';
import BaseComponent from '../../components/BaseComponent.js';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import _mergeJSXProps from '@vue/babel-helper-vue-jsx-merge-props';
import '../../components/Button/BaseButton.js';
import { ActionButton } from '../../components/Button/ActionButton/ActionButton.js';
import '../../components/Button/DefaultButton/DefaultButton.js';
import '../../components/Button/PrimaryButton/PrimaryButton.js';
import '../../components/Button/CommandBarButton/CommandBarButton.js';
import '../../components/Button/CompoundButton/CompoundButton.js';
import '../../components/Button/IconButton/IconButton.js';
import '../../components/Button/MessageBarButton/MessageBarButton.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

var GridCell = function (_BaseComponent) {
  _inherits(GridCell, _BaseComponent);

  var _super = _createSuper(GridCell);

  function GridCell() {
    _classCallCheck(this, GridCell);

    return _super.apply(this, arguments);
  }

  _createClass(GridCell, [{
    key: "render",
    value: function render() {
      var _css;

      var h = arguments[0];
      var className = this.className,
          item = this.item,
          cellDisabledStyle = this.cellDisabledStyle,
          cellIsSelectedStyle = this.cellIsSelectedStyle,
          selected = this.selected,
          disabled = this.disabled;
      return h(ActionButton, _mergeJSXProps([{
        "class": css(className, (_css = {}, _defineProperty(_css, '' + cellIsSelectedStyle, selected), _defineProperty(_css, '' + cellDisabledStyle, disabled), _css)),
        "attrs": {
          "getClassNames": this.getClassNames
        }
      }, {
        scopedSlots: {
          flex: this.$scopedSlots.default
        }
      }]));
    }
  }]);

  return GridCell;
}(BaseComponent);

__decorate([Prop({
  type: Object,
  default: function _default() {}
}), __metadata("design:type", Object)], GridCell.prototype, "item", void 0);

__decorate([Prop({
  type: Boolean
}), __metadata("design:type", Boolean)], GridCell.prototype, "disabled", void 0);

__decorate([Prop({
  type: Boolean
}), __metadata("design:type", Boolean)], GridCell.prototype, "selected", void 0);

__decorate([Prop({
  type: String
}), __metadata("design:type", String)], GridCell.prototype, "cellDisabledStyle", void 0);

__decorate([Prop({
  type: String
}), __metadata("design:type", String)], GridCell.prototype, "cellIsSelectedStyle", void 0);

__decorate([Prop(), __metadata("design:type", Object)], GridCell.prototype, "getClassNames", void 0);

GridCell = __decorate([Component({
  components: {
    ActionButton: ActionButton
  }
})], GridCell);

export { GridCell };
